==> kplatforms-8.x-3.6.tar.gz: kplatforms/INSTALL.md <==
KPLATFORMS
----------

Download Kplatforms
-------------------

Download kplatforms somewhere convenient, such as:

    $ git clone --branch lock http://git.drupal.org/project/kplatforms.git ~/makefiles/kplatforms

Install Drush 7.x
-----------------

To use the latest version of kplatforms effectively, you need a recent version
of Drush, as well as a custom Drush extension. As such, we recommend using a
local Drush install, so as not to interfere with other Drush functionality on
the server.

    $ git clone https://github.com/drush-ops/drush.git ~/drush7
    $ cd ~/drush7
    $ curl -sS https://getcomposer.org/installer | php
    $ php ./composer.phar install
    $ alias drush7="~/drush7/drush"

You can test whether the 'drush7' alias is working like so:

    $ drush7 status
     PHP configuration      :  /etc/php5/cli/php.ini
     PHP OS                 :  Linux
     Drush version          :  7.0-dev
     Drush temp directory   :  /tmp
     Drush configuration    :
     Drush alias files      :

Until the stable release of Drush 7, you should see '7.0-dev' listed as the
'Drush version'.

If you are running PHP with the suhosin module, you may have to pass the PHP
CLI an option to allow .phar files:

    -d suhosin.executor.include.whitelist=phar


Install make_diff
-----------------

The 'make_diff' extension allows two makefiles to be compared easily. Since it
is not published yet, we cannot install it via 'drush dl'. Instead, clone the
repo from github. We put it directly in the local drush install so as to keep
it isolated from other Drush functionality on the server.

    $ git clone https://github.com/PraxisLabs/make_diff.git ~/.drush/commands/make_diff
    $ drush cc drush
    $ drush | grep make-diff

==> kplatforms-8.x-3.39.tar.gz: kplatforms/INSTALL.md <==
KPLATFORMS
----------

Download Kplatforms
-------------------

Download kplatforms somewhere convenient, such as:

    $ git clone --branch lock http://git.drupal.org/project/kplatforms.git ~/makefiles/kplatforms

Install Drush 7.x
-----------------

To use the latest version of kplatforms effectively, you need a recent version
of Drush, as well as a custom Drush extension. As such, we recommend using a
local Drush install, so as not to interfere with other Drush functionality on
the server.

To install drush 7, follow the documentation at http://docs.drush.org/en/7.x/ or use the
git branch as indicated below. (Note: master will contain future versions, so make sure to use the 7.x
branch only).

    
    $ git clone -b 7.x https://github.com/drush-ops/drush.git ~/drush7
    $ cd ~/drush7
    $ curl -sS https://getcomposer.org/installer | php
    $ php ./composer.phar install
    $ alias drush7="~/drush7/drush"

You can test whether the 'drush7' alias is working like so:

    $ drush7 status
     PHP configuration      :  /etc/php5/cli/php.ini
     PHP OS                 :  Linux
     Drush version          :  7.0-dev
     Drush temp directory   :  /tmp
     Drush configuration    :
     Drush alias files      :

Until the stable release of Drush 7, you should see '7.0-dev' listed as the
'Drush version'.

If you are running PHP with the suhosin module, you may have to pass the PHP
CLI an option to allow .phar files:

    -d suhosin.executor.include.whitelist=phar


Install make_diff
-----------------

The 'make_diff' extension allows two makefiles to be compared easily. Since it
is not published yet, we cannot install it via 'drush dl'. Instead, clone the
repo from github. We put it directly in the local drush install so as to keep
it isolated from other Drush functionality on the server.

    $ git clone https://github.com/PraxisLabs/make_diff.git ~/.drush/commands/make_diff
    $ drush cc drush
    $ drush | grep make-diff
